browse: Open a browser window to display a Neotoma dataset within the Neotoma Explorer
Description
Using a download or dataset object, open up a browser window in the users default browser. Passing a download_list or dataset_list will open Neotoma Explorer with the first object and return a warning.
Usage
browse(x)
Arguments
x
A numeric value for the dataset ID, a dataset or download object.
Value
Returns a NULL value, opens a browser.
References
Neotoma Project Website: http://www.neotomadb.org
API Reference: http://api.neotomadb.org/doc/resources/sites