Learn R Programming

neotoma (version 1.5.0)

get_chroncontrol.download: Function to return chronological control tables from a download object.

Description

Using a download, return the default chron-control table as a data.frame.

Usage

## S3 method for class 'download':
get_chroncontrol(x, verbose = TRUE, add = FALSE)

Arguments

x
A single download object.
verbose
logical; should messages on API call be printed?
add
Should the chroncontrol be added to the download object (default FALSE)