Rdocumentation
powered by
Learn R Programming
neotoma (version 1.3.0)
get_contacts: Get contact information.
Description
Deprecated - see
get_contact
.
Usage
get_contacts(contactid, contactname, contactstatus, familyname)
Arguments
contactid
Contact ID is a numerical value associated with the Neotoma Contact table's numerical Contact ID.
contactname
A character string indicating the data contributors' project, organization or personal name. May be a partial string and can include wildcards.
contactstatus
The current status of the contact. Possible values include: active, deceased, defunct, extant, inactive, retired, unknown.
familyname
A character string. Full or partial string indicating the contact's last name.
References
Neotoma Project Website: http://www.neotomadb.org API Reference: http://api.neotomadb.org/doc/resources/contacts