Learn R Programming

neotoma (version 1.5.0)

get_dataset.geochronologic: Obtain dataset information from an object of class geochronologic.

Description

A function to access the Neotoma API and return datasets corresponding to the parameters defined by the user.

Usage

## S3 method for class 'geochronologic':
get_dataset(x, ...)

Arguments

x
An object of class geochronologic.
...
objects passed from the generic. Not used in the call.