Learn R Programming

neotoma (version 1.4.0)

get_download.dataset_list: Function to return full download records using a dataset_list.

Description

Using a dataset_list, return all records associated with the data as a download_list.

Usage

## S3 method for class 'dataset_list':
get_download(x, verbose = TRUE)

Arguments

x
An object of class dataset_list.
verbose
logical; should messages on API call be printed?