Learn R Programming

neotoma (version 1.3.0)

get_download.default: Function to return full download records using numeric dataset IDs.

Description

Using the dataset ID, return all records associated with the data as a download_list.

Usage

## S3 method for class 'default':
get_download(x, verbose = TRUE)

Arguments

x
A single numeric dataset ID or a vector of numeric dataset IDs as returned by get_datasets.
verbose
logical; should messages on API call be printed?