Learn R Programming

neotoma (version 1.2-0)

get_publication.default: A function to get publications for sites or datasets in the Neotoma Database using the API.

Description

The function takes the parameters, defined by the user, and returns a table with publication information from the Neotoma Paleoecological Database.

Usage

## S3 method for class 'default':
get_publication(x, contactid, datasetid, author, pubtype,
  year, search)

Arguments

x
Numeric Publication ID value, either from get_dataset or known.
contactid
Numeric Contact ID value, either from get_dataset or get_contact
datasetid
Numeric Dataset ID, known or from get_dataset
author
Character string for full or partial author's name. Can include wildcards such as 'Smit*' for all names beginning with 'Smit'.
pubtype
Character string, one of eleven allowable types, see get_table. For a list of allowed types run get_table("PublicationTypes").
year
Numeric publication year.
search
A character string to search for within the article citation.