Learn R Programming

neotoma (version 1.3.0)

get_publication.download_list: A function to get publications for datasets in the Neotoma Database using the API.

Description

The function takes a download_list and returns a table with publication information from the Neotoma Paleoecological Database.

Usage

## S3 method for class 'download_list':
get_publication(x, ...)

Arguments

x
an object of class download_list.
...
objects passed from the generic. Not used in the call.