Learn R Programming

neotoma (version 1.3.0)

get_site: Return Site Information.

Description

Return site information from the Neotoma Paleoecological Database. get_site returns site information from the Neotoma Paleoecological Database based on parameters defined by the user.

Usage

get_site(sitename, altmin, altmax, loc, gpid, ...)

Arguments

sitename
character string representing the full or partial site name, or an object of class dataset, dataset_list, download or download_list
altmin
Minimum site altitude (in m).
altmax
Maximum site altitude (in m).
loc
A numeric vector c(lonW, latS, lonE, latN) representing the bounding box within which to search for sites. The convention here is to use negative values for longitudes west of Grewnwich or longitudes south of the equator.
gpid
A character string or numeric value, must correspond to a valid geopolitical identity in the Neotoma Database. Use get.tables('GeoPoliticalUnits') for a list of acceptable values, or link here: http://api.neotomadb.org/apdx/geopol.htm
...
Optional additional arugments

Value

  • A data frame:
  • siteidUnique database record identifier for the site.
  • sitenameName of the site.
  • longMean longitude, in decimal degrees, for a site (-180 to 180).
  • latMean latitude, in decimal degrees, for a site (-90 to 90).
  • elevElevation in meters.
  • descriptionFree form description of a site, including such information as physiography and vegetation around the site.
  • long_accIf the site is described by a bounding box this is the box width.
  • lat_accIf the site is described by a bounding box this is the box height.

References

Neotoma Project Website: http://www.neotomadb.org API Reference: http://api.neotomadb.org/doc/resources/sites

Examples

Run this code
#  What is the distribution of site elevations in Neotoma?
all.sites <- get_site()  #takes a bit of time.

plot(density(all.sites$elev, from = 0, na.rm=TRUE),
main = 'Altitudinal Distribution of Neotoma Sites', xlab = 'Altitude (m)', log='x')

#  Get site information from a dataset:
nw.datasets <- get_dataset(loc = c(-140, 50, -110, 65), datasettype='pollen',taxonname='Pinus*')
nw.sites <- get_site(nw.datasets)

Run the code above in your browser using DataLab