Learn R Programming

neotoma (version 1.3.0)

get_sites: Return Site Information.

Description

Deprecated, see get_site

Usage

get_sites(sitename, altmin, altmax, loc, gpid)

Arguments

sitename
A character string representing the full or partial site name.
altmin
Minimum site altitude (in m).
altmax
Maximum site altitude (in m).
loc
A numeric vector c(lonW, latS, lonE, latN) representing the bounding box within which to search for sites. The convention here is to use negative values for longitudes west of Grewnwich or longitudes south of the equator.
gpid
A character string or numeric value, must correspond to a valid geopolitical identity in the Neotoma Database. Use get.tables('GeoPoliticalUnits') for a list of acceptable values, or link here: http://api.neotomadb.org/apdx/geopol.htm

References

Neotoma Project Website: http://www.neotomadb.org API Reference: http://api.neotomadb.org/doc/resources/contacts