Learn R Programming

neotoma (version 1.3.0)

get_taxa: Get taxon information from Neotoma.

Description

Get taxon information from Neotoma.

Usage

get_taxa(taxonid, taxonname, status, taxagroup, ecolgroup)

Arguments

taxonid
Numeric taxon identifier used in Neotoma
taxonname
A character string representing the full or partial name of taxa of interest.
status
The current status of the taxon, one of 'extinct', 'extant', 'all'.
taxagroup
The taxonomic grouping for the taxa. See http://api.neotomadb.org/doc/resources/taxa for the list of approved groupings.
ecolgroup
The ecological group of the taxa. More detailed than taxagroup, can be obtained using get_table("EcolGroupTypes").

Value

  • Returns a data frame with the following components:
  • TaxonIDUnique database record identifier for a taxon
  • TaxonCodeShorthand notation for a taxon identification
  • TaxonNameName of the taxon
  • AuthorAuthor(s) of the name. Used almost exclusively with beetle taxa
  • ExtinctTrue if extinct; false if extant
  • TaxaGroupCode for taxa group to which taxon belongs
  • EcolGroupsArray of ecological group codes to which the taxon belongs
  • HigherTaxonIDTaxonID of the next higher taxonomic rank
  • PublicationIDPublication identification number
  • NotesFree-form notes or comments about the taxon

References

Neotoma Project Website: http://www.neotomadb.org API Reference: http://api.neotomadb.org/doc/resources/contacts

Examples

Run this code
## Return all species taxa with "Abies" in name - note wildcard
taxa <- get_taxa(taxonname = "Abies*")

Run the code above in your browser using DataLab