Learn R Programming

neotoma (version 1.3.0)

pollen.equiv: A table to convert the pollen taxa identified by investigators to standardized lists.

Description

A list of standardized (published) taxonomies from the literature to help standardize taxonomies for synthesis work.

Usage

translate.table

Arguments

format

a data.frame object

Details

Taxon conversion table (readable).