Learn R Programming

neotoma (version 1.3.0)

translate.table: A table to convert the original taxa to standardized lists.

Description

A list of standardized (published) taxonomies from the literature to help standardize taxonomies for synthesis work.

Usage

translate.table

Arguments

format

a data.frame object

source

The Neotoma database.