Rdocumentation
powered by
Learn R Programming
neotoma (version 1.2-0)
download: A class for download objects.
Description
A
download
is an object with the full record for a single dataset. A
download
is an object with the full record for a single dataset.
Arguments
Details
TO DO TO DO