Learn R Programming

neotoma (version 1.3.0)

get_chroncontrol: Function to return chronological control tables used to build age models.

Description

Using the dataset ID, return all records associated with the data. At present, only returns the dataset in an unparsed format, not as a data table. This function will only download one dataset at a time.

Usage

get_chroncontrol(x, verbose = TRUE)

Arguments

x
A single numeric chronology ID or a vector of numeric dataset IDs as returned by get_dataset.
verbose
logical, should messages on API call be printed?

Value

  • This command returns either an object of class "try-error" containing the error returned from the Neotoma API call, or a full data object containing all the relevant information required to build either the default or prior chronology for a core. This is a list comprising the following items:
  • chron.controlA table describing the collection, including dataset information, PI data compatable with get_contact and site data compatable with get_site.
  • metaDataset information for the core, primarily the age-depth model and chronology. In cases where multiple age models exist for a single record the most recent chronology is provided here.
  • If Neotoma returns empty content, either the control table or the associated metadata (which happens in approximately 25

References

Neotoma Project Website: http://www.neotomadb.org API Reference: http://api.neotomadb.org/doc/resources/contacts

Examples

Run this code
#  The point of pulling chronology tables is to re-build or examine the chronological
#  information that was used to build the age-depth model for the core.

Run the code above in your browser using DataLab