get_contact(contactid, contactname, contactstatus, familyname)"try-error" describing
the reason for failure (either mis-defined parameters or an error from the Neotoma API),
or a table of contacts, with rows corresponding to the number of individual
contacts returned by the Neotoma API. Each row entry includes the following parameters:contact.name"Simpson, George Gaylord") or name of organization or project (e.g. "Great Plains Flora Association").contact.statusfamily.nameleading.initials"G.G.").given.names"George Gaylord"). Initials with spaces are used if full given names are not known (e.g. "G. G").suffix"Jr.", "III").title"Dr.", "Prof.", "Prof. Dr").phonefaxemailurladdressnotescontact.idalias.id# To find all data contributors who are active:
active.cont <- get_contact(contactstatus = 'active')
# To find all data contributors who have the last name "Smith"
smith.cont <- get_contact(familyname = 'Smith')Run the code above in your browser using DataLab