Rdocumentation
powered by
Learn R Programming
neotoma (version 1.3.0)
get_publication.download: A function to get publications for downloads in the Neotoma Database using the API.
Description
The function takes a
download
and returns a table with publication information from the Neotoma Paleoecological Database.
Usage
## S3 method for class 'download': get_publication(x, ...)
Arguments
x
an object of class
download
.
...
objects passed from the generic. Not used in the call.