translate.table: A table to convert the original taxa to standardized lists.
Description
A list of standardized (published) taxonomies from the literature to help standardize taxonomies for synthesis work.format
a data.frame objectsource
The Neotoma database.